/***************************************************************************
 *   Copyright (C) 2007 by Jackie Team   *
 *   jackie.team@gmail.com   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#include "options_Dialog.h"
#include "images/icon.xpm"


BEGIN_EVENT_TABLE ( OptionsDialog, wxFrame )
    EVT_BUTTON(ID_SAVE,OptionsDialog::save)
    EVT_BUTTON(ID_CANCEL,OptionsDialog::cancel)
    EVT_TEXT(ID_REPLACE,OptionsDialog::textWriting)
END_EVENT_TABLE()



OptionsDialog::OptionsDialog(wxWindow * parent):wxFrame(parent,wxID_ANY, _T("Options"),wxDefaultPosition, wxDefaultSize, wxDEFAULT_FRAME_STYLE& ~ ( wxRESIZE_BORDER | wxRESIZE_BOX | wxMAXIMIZE_BOX ) | wxFRAME_FLOAT_ON_PARENT){
#ifndef __WXMSW__
	wxIcon icone=wxIcon ( icon_xpm );
#else
    wxIcon icone=wxIcon(_T("A"));
#endif
    SetIcon(icone);
    wxPanel  *pBas=new wxPanel(this),
             *pHaut=new wxPanel(this);
    btnCancel = new wxButton(pBas,ID_CANCEL,_("Cancel"));
    btnSave = new wxButton(pBas,ID_SAVE,_("Save"));
    wxStaticText* txtReplace=new wxStaticText(pHaut,wxID_ANY,_("Replace character")),
                  *txtDir=new wxStaticText(pHaut,wxID_ANY,_("Remember the current directory when closing")),
                  *txtSort=new wxStaticText(pHaut,wxID_ANY,_("Sort by directory"));
    defaultReplaceChar = new wxTextCtrl(pHaut,ID_REPLACE,_T(""));
    saveDir = new wxCheckBox(pHaut,wxID_ANY,_T(""));
    directorySort = new wxCheckBox(pHaut,wxID_ANY,_T(""));
    
    wxBoxSizer *saveCancelSizer = new wxBoxSizer( wxHORIZONTAL ),*replaceSizer=new wxBoxSizer( wxHORIZONTAL ),
               *dirSizer=new wxBoxSizer( wxHORIZONTAL ),*sortSizer=new wxBoxSizer( wxHORIZONTAL ),
               *globalSizer=new wxBoxSizer( wxVERTICAL ),*hautSizer=new wxBoxSizer( wxVERTICAL ),*basSizer=new wxBoxSizer( wxVERTICAL );
    wxGridSizer* gpSizer = new wxGridSizer(1);
    
    replaceSizer->Add(8,0,0);
    replaceSizer->Add(txtReplace,0,wxALIGN_LEFT|wxALL|wxALIGN_CENTER_VERTICAL);
    replaceSizer->Add(5,0,0);
    replaceSizer->Add(defaultReplaceChar,0,wxALIGN_LEFT|wxALL|wxALIGN_CENTER_VERTICAL);
    replaceSizer->Add(8,0,0);

    dirSizer->Add(8,0,0);
    dirSizer->Add(saveDir,0,wxALIGN_LEFT|wxALL|wxALIGN_CENTER_VERTICAL);
    dirSizer->Add(5,0,0);
    dirSizer->Add(txtDir,0,wxALIGN_LEFT|wxALL|wxALIGN_CENTER_VERTICAL);
    dirSizer->Add(8,0,0);

    sortSizer->Add(8,0,0);
    sortSizer->Add(directorySort,0,wxALIGN_LEFT|wxALL|wxALIGN_CENTER_VERTICAL);
    sortSizer->Add(5,0,0);
    sortSizer->Add(txtSort,0,wxALIGN_LEFT|wxALL|wxALIGN_CENTER_VERTICAL);
    sortSizer->Add(8,0,0);
    
    saveCancelSizer->Add(1,1,1);
    saveCancelSizer->Add(btnSave,0,wxALIGN_RIGHT|wxEXPAND|wxALL);
    saveCancelSizer->Add(5,0,0);
    saveCancelSizer->Add(btnCancel,0,wxALIGN_RIGHT|wxEXPAND|wxALL);
    saveCancelSizer->Add(5,0,0);
    
    basSizer->Add(0,5,0);
    basSizer->Add(saveCancelSizer,1, wxEXPAND|wxALL);
    basSizer->Add(0,5,0);
    
    pBas->SetSizer ( basSizer );
    
    hautSizer->Add(0,5,0);
    hautSizer->Add(dirSizer,1, wxEXPAND|wxALL);
    hautSizer->Add(sortSizer,1, wxEXPAND|wxALL);
    hautSizer->Add(replaceSizer,1, wxEXPAND|wxALL);
    hautSizer->Add(0,5,0);
    
    pHaut->SetBackgroundColour(wxColour(255,255,255));
    pHaut->SetSizer(hautSizer);
    
    globalSizer->Add(pHaut,1, wxEXPAND|wxALL,1);
    globalSizer->Add(pBas,0, wxEXPAND|wxALL);
    SetSizer(globalSizer);
    globalSizer->Fit(this);

    SetAutoLayout ( true );

    //read options
    OptionsHandler::readOptions();
    wxRegEx speCharExp(wxT("[\\:*?\"<>|/]"));
    wxString rep=OptionsHandler::getOption(_T("replace_char"));
    //remove specials chars for textWriting
    speCharExp.Replace(&rep,wxString(_T("")),0);
    defaultReplaceChar->SetValue(rep);
    wxString sd=OptionsHandler::getOption(_T("save_dir"));
    wxString ds=OptionsHandler::getOption(_T("sort_by_dir"));
    saveDir->SetValue((sd==_T("1")));
    directorySort->SetValue((ds==_T("1")));

}

void OptionsDialog::save(wxCommandEvent& e){
    OptionsHandler::setOption(_T("replace_char"),defaultReplaceChar->GetValue());
    OptionsHandler::setOption(_T("save_dir"),wxString::Format(_T("%d"),saveDir->IsChecked()));
    OptionsHandler::setOption(_T("sort_by_dir"),wxString::Format(_T("%d"),directorySort->IsChecked()));
    OptionsHandler::writeOptions();
    Destroy();
}

void OptionsDialog::cancel(wxCommandEvent& e){
    Destroy();
}

void OptionsDialog::textWriting(wxCommandEvent& event){
    wxString s = defaultReplaceChar->GetValue();
    long offset=1;
    if (s.Find(_T('\\')) != wxNOT_FOUND or s.Find (_T(':')) != wxNOT_FOUND or s.Find (_T('*')) != wxNOT_FOUND or s.Find (_T('?')) != wxNOT_FOUND or s.Find (_T('\"')) != -1 or s.Find (_T('<')) != -1 or s.Find (_T('>')) != -1 or s.Find (_T('|')) != wxNOT_FOUND or s.Find (_T('/')) != wxNOT_FOUND){
        defaultReplaceChar->Remove(defaultReplaceChar->GetLastPosition() - offset,defaultReplaceChar->GetLastPosition()-offset+1);
    }
}

